    /*! \mainpage About

      HYDJET++ , event generator under the ROOT FRAMEWORK for simulation of relativistic heavy ion AA collisions as a superposition of the soft, hydro-type state and the hard, multi-parton state.                       
                                                                              
      The main routine is written in the object-oriented C++ language under the ROOT environment. The hard, multi-partonic part of HYDJET++ event is identical to the hard part of Fortran-written HYDJET (PYTHIA6.4xx + PYQUEN1.5.x) and is included in the generator structure as the separate directory. The soft part of HYDJET++ event represents the thermal hadronic state obtained with the Bjorken-like parameterization of freeze-out hypersurface and includes longitudinal, radial and elliptic flow effects and decays of hadronic resonances. The corresponding fast Monte-Carlo simulation procedure (C++ code) FAST MC is adapted.         
      
      Web-page:                                                               
      http://cern.ch/lokhtin/hydjet++                                         

      Installation information is present on \ref page1

 \copyright                                                                  
  This program is a free software; one can use and redistribute it freely.    
  Any publication of results obtained using this code must reference          
                  
  
                                                                              
 \section ref_sec Original papers
                                                                              
      Main reference for HYDJET++:                                            
      I.P. Lokhtin, L.V. Malinina, S.V. Petrushanko, A.M. Snigirev,           
      I. Arsene, K. Tywoniuk, Comp. Phys. Comm. 180 (2009) 779;               
      http://cern.ch/lokhtin/hydjet++.                                        
                                                                              
      Reference for HYDJET and PYQUEN:                                        
      I.P. Lokhtin, A.M. Snigirev, Eur. Phys. J. C 46 (2006) 211;             
      http://cern.ch/lokhtin/hydro/hydjet.html                                
      http://cern.ch/lokhtin/pyquen.
 
 
      Reference for PYTHIA6.4:                                               
      T.Sjostrand, S. Mrenna and P. Skands, JHEP05 (2006) 026;                
      http://home.thep.lu.se/~torbjorn/Pythia.html.                           
                                                                              
      References for FAST MC:                                                 
      N.S. Amelin, R. Lednicky, T.A. Pocheptsov, I.P. Lokhtin,                
      L.V. Malinina, A.M. Snigirev, Iu.A. Karpenko and Yu.M. Sinyukov,        
      Phys. Rev. C 74 (2006) 064901;                                          
      N.S. Amelin, I. Arsene, L. Bravina, Iu.A. Karpenko, R. Lednicky,        
      I.P. Lokhtin, L.V. Malinina, A.M. Snigirev and Yu.M. Sinyukov,          
      Phys. Rev. C 77 (2008) 014903;                                          
      http://uhkm.jinr.ru.                                                    
                                                                              
      Reference for nuclear shadowing model:                                  
      K. Tywoniuk, I.C. Arsene, L. Bravina, A. Kaidalov and                   
      E. Zabrodin, Phys. Lett. B 657 (2007) 170.                              
                                                                              
 \version     Version 2.4:                                                            
                                                                              
 \authors
      Igor Lokhtin, SINP MSU, Moscow, RU                                      
      e-mail: Igor.Lokhtin@cern.ch      
      Ludmila Malinina, SINP MSU, Moscow, RU                                  
      e-mail: malinina@lav01.sinp.msu.ru
 
 
 \page page1 Short documentation
      \tableofcontents
      This is short documentation. For detailed one please see papers listed on \ref index. Update list is on \ref page2 

\section phys_val Physics validity of the model 

-# HYDJET++ is only applicable for symmetric AA collisions of heavy (A>40) ions at high energies (c.m.s. energy >~10 GeV per nucleon pair). 
-# Hydro-type approximation for heavy ion collisions is expected to be 
applicable for central and semi-central collisions. The result obtained for 
very peripheral collisions (b~2*RA) can be not adequate. 

-# We do not expect correct event description for very forward rapidities 
(|y|>3), where other mechanisms of particle production among hydro-flow and
jets can be important. 

-# Physics model for description of medium-induced gluon radiation is based on 
Baier-Dokshitzer-Mueller-Schiff formalism and valid for relatively high
transverse momenta of jet partons (>> 1 GeV/c). Thus setting reasonably high values of minimum pt in initial hard parton sub-processes (parameter 'ptmin') 
is preferable.
  
   \section install_sec Installation

    To install HYDJET++ required:
    -# the FORTRAN compiler
    -# cmake version >= 3.5
    -# C++11 support compiller
    -# ROOT v5.22 or leter

    After unpacking .tar archive in HYDJET++ folder one can build it with/without
    binary test file. Shared LIBRARY will be created in lib/ folder.

   \subsection install_sec_linux Installation on LINUX:
    For each new architecture please make sure You cleaned up the old files!

    \subsubsection install_sec_linux_def To use default mode (with binnary test file) please use shell command
 
        ./runconfigure

    The result would be placed to folder ../HYDJET++2.4.x:
        - lib/        - library folde
        - Hy2Input    - input parameters text file (by default Antares5 tune)
        - hydjet_test - test binary file
        - tunes/      - default tunes set (just replace Hy2Input with any of them)
        - RootMacros/ - examples of macros for analyzing the output of the root tuple

    \subsubsection install_sec_linux_histo To use HISTO mode (instead of tuple one) for output, please use 

        ./runconfigure histo 

    or uncoment the following preprocessor directive in the test/RunHadronSourceHISTO.cxx:

        #define HISTO_MODE
        
    and do 

        ./runconfigure 

     NOTE!!! the folder "test" will be available only after first compilation!

    \subsubsection install_sec_linux_lib To build HYDJET++ library without binary test file please use just

        ./configure --lib

    To use created shared library (by default in ../HYDJET++2.4.x/lib), one can compile his owen code with g++ for example:

        g++ -Wall -g -o Hyjet2 RunHadronSourceHISTO.cxx -lhydjet2 -Llib -L/usr/lib64/root -lGui -lCore -lImt -lRIO -lNet -lHist -lGraf -lGraf3d -lGpad -lROOTDataFrame -lROOTVecOps -lTree -lTreePlayer -lRint -lPostscript -lMatrix -lPhysics -lMathCore -lThread -lMultiProc -pthread -lm -ldl -rdynamic -pthread -std=c++17 -m64 -I/usr/include/root -L/usr/lib64/root -lCore -lImt -lRIO -lNet -lHist -lGraf -lGraf3d -lGpad -lROOTDataFrame -lROOTVecOps -lTree -lTreePlayer -lRint -lPostscript -lMatrix -lPhysics -lMathCore -lThread -lMultiProc -pthread -lm -ldl -rdynamic

    The interface files needed for using such library is Hydjet2.h and InitialParams.h. One also have to care about export lib/ folder: 
        
        export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:lib"

    \subsubsection install_sec_linux_hep To build HYDJET++ program with HepMC output format please do

        ./configure --build-test --HepMC-output

    \subsubsection install_sec_linux_list To list all avaible options do:

        ./configure --help

    NOTE!!! Some of the modern compiler using the new linker which has a
    different behaviour under many respect, and in particular it doesn't
    initialize correctly the common block coming from pydata because of how
    the dependency chain is structured. In this case the following message
    will be showed:

        Fatal error: BLOCK DATA PYDATA has not been loaded!
        The program execution is stopped now!

    In this case, please use PYTHIA from source (--build-pythia option):

        ./configure --build-pythia --build-test

    for HYDJET++ library with binary. And for HYDJET++ library only:

        ./configure --build-pythia


   \subsection install_sec_other Installation on other platforms:

    To install on other platforms please use cmake-gui with CMakeLists.txt

\section input_info Input information

Run of the program (from ../HYDJET++2.4.x) is controlled by the file "Hy2Input" for different
type of input parameters. All available parameter sets listed on the web-site.

The following input parameters should be specified:

 - fNevnt - number of events to generate;
 - femb   - embedding flag, to switch on embedding mode (reading underline event for each generated one, to proper mixing later) <br>
         =0 embedding is off, <br>
         =1 simple embedding mode, <br>
         =2 special emedding mode for Pyquen, with correction of the number of NN sub-collisions (subtracting sub-collision to replace it by Pyquen's one) <br>
 - fSqrtS - c.m.s. energy per nucleon pair in GeV;
 - fAw - atomic weight of nuclei;
 - fIfb  - flag of type of centrality generation <br>
         =0 impact parameter is fixed (fBfix ) <br>
         >0 impact parameter is generated with standard Glauber geometry between minimum (fBmin) and maximum (fBmax) values; <br>
 - fBmin - minimum impact parameter in units of nucleus radius RA;*
 - fBmax - maximum impact parameter in units of nucleus radius RA;*
 - fBfix - fixed impact parameter in units of nucleus radius RA.

The following input parameters may be changed by user from their default values.

 - fSeed - parameter to set the random number seed <br>
         =0 the current time is used to set the random generator seed <br>
         >0 the value "fSeed" is used to set the random generator seed (then state of random number generator in PYTHIA MRPY(1)=fSeed) (default: fSeed=0);

Parameters for soft hydro-type part of the event.

 - fT- chemical freeze-out temperature in GeV;
 - fMuB - chemical baryon potential per unit charge in GeV;
 - fMuS - chemical strangeness potential per unit charge in GeV;
 - fMuC - chemical charm potential per unit charge in GeV;
 - fMuI3 - chemical isospin potential per unit charge in GeV;
 - fTthFO - thermal freeze-out temperature in GeV;
 - fMu_th_pip - chemical potential of positively charged pions at thermal
 - freeze-out in GeV;
 - fTau - proper time at thermal freeze-out for central collisions in fm/c;
 - fSigmaTau - duration of emission at thermal freeze-out for central collisions in fm/c;
 - fR - maximal transverse radius at thermal freeze-out for central collisions in fm;
 - fYlmax - maximal longitudinal flow rapidity at thermal freeze-out;
 - fUmax - maximal transverse flow rapidity at thermal freeze-out for central collisions;
 - fRhou2, fRhou3, fRhou3 - parameters to specify/switch on(>0)/off(0) elliptic,
  triangular and quadrangular modulations of the collective velocity profile
  respectively for the alternative scenario of anisotropic flow treatment
  (L.V. Bravina et al., Eur. Phys. J. C 74 (2014) 2807) (default: 0., 0., 0.);
 - fDelta - momentum azimuthal anizotropy parameter at thermal freeze-out
  (for given centrality class);
 - fEpsilon - spatial azimuthal anisotropy parameter at thermal freeze-out
  (for given centrality class);
 - fKeps2, fKeps3 - parameters to specify/switch on(>0)/off(0) the strenght of
  elliptic and triangular flow fluctuations respectively
  (L.V. Bravina et al., Eur. Phys. J. C 75 (2015) 588) (default: 0.34, 0.52);
 - fIfDeltaEpsilon - flag to specify fDelta and fEpsilon values (if =0 -
  specified by user values are used, if >=1 - calculated values are used)
  (default: 0.);
 - fDecay - flag to include hadron decays (if =0 - off, if >=1 - on)
  (default: 1.);
 - fWeakDecay - low decay width threshold in GeV (if width < fWeakDecay - decay
  off, width >= fDecayWidth - decay on; can be used to switch off weak decays)
  (default: 0.);
 - fEtaType - flag to specify longitudinal flow rapidity distribution
  (if =0 - uniform in the range [-fYlmax,fYlmax], if >0 - Gaussian with
  the dispersion fYlmax (default: 1);
 - fTMuType - flag to use calculated chemical freeze-out temperature, baryon and
  strangeness potentials as a function of 'fSqrtS' (if =0 - specified by user
  values are used, if >0 - calculated values are used) (default: 0);
 - fCorrS - flag and value to include strangeness supression with fCorrS value:
  (0 < fCorrS =< 1, if fCorrS =< 0 then it is calculated as a function of
  chemical freeze-out temperature and baryon potential, default: 1);
 - fIcharm - flag to include thermal charm production (=0 no charm production,
   >=1 charm production) (default: 0);
 - fCorrC - flag and value to include charmness enhancement with fCorrC value:
  (fCorrC > 0, if fCorrC =< 0 then it is calculated with PYTHIA, default: -1).

Parameters for treatment of hard multi-partonic part of the event.

 - fNhsel - flag to include jet and hydro state production (default: 2) <br>
  (0 - jet production off, hydro on) <br>
  (1 - jet production on, jet quenching off, hydro on) <br>
  (2 - jet production on, jet quenching on, hydro on) <br>
  (3 - jet production on, jet quenching off, hydro off) <br>
  (4 - jet production on, jet quenching on, hydro off); <br>
 - fIshad - flag to include impact parameter dependent nuclear shadowing
  for gluons and light sea quarks (u,d,s) (default: 1):
  (0 - no shadowing, 1 - shadowing is included);
 - fPtmin - minimal pt of parton-parton scattering in PYTHIA event in GeV
  (the PYTHIA parameter ckin(3)=fPtmin);
 - fIedit - flag to suppress the output of particle history from PYTHIA (=1 only
  final state particles; =0 full particle history from PYTHIA) (default: 1).

PYQUEN energy loss model parameters,
  - fT0 - initial maximum temperature (in GeV) of quark-gluon plasma for central
   PbPb collisions at mid-rapidity (initial temperature for other centralities
   and atomic numbers will be calculated automatically)
   (allowed range is 0.2 < fT0 < 2.);
  - fTau0 - proper time of quark-gluon plasma formation in fm/c
   (allowed range is 0.01 < fTau0 < 10.);
  - fNf - number of active quark flavours in quark-gluon plasma
  - (fNf=0, 1, 2 or 3);
  - fIenglu - flag to fix type of in-medium partonic energy loss (default: 0)
   (fIenglu=0 - radiative and collisional loss,
  - fIenglu=1 - radiative loss only, fIenglu=2 - collisional loss only);
  - fIanglu - flag to fix type of angular distribution of in-medium
  emitted gluons (default: 0)
   (fIanglu=0 - small-angular, fIanglu=1 - wide-angular, fIanglu=2 - collinear).

A number of important PYTHIA parameters also may be changed/specified in
PythiaTune (by default) file. The rest PYTHIA parameters may be changed (if it is
necessary) using corresponding common blocks in the file "progs_fortran.f".

NOTE! If specified by user value of such parameter extends out of allowed
range, its default value is used in HYDJET++ run.

NOTE! At this moment nuclear shadowing parameterization is implemented only
      for Pb, Au, Pd or Ca ions.


\section out_info Output information (standard tuple)

The program output is directed to ROOT file specified by the user in the
command line, or by default to "Hydjet2_tuple.root". The output file contains a
tree named "td", which keeps the entire event record including primary particles
and decay products with their coordinates and momenta information. Each decay
product contains the unique index of its parent particle so that the entire
event history may be obtained. Besides particle information, the output file
contains also the following global output parameters for each event.

- Bgen - generated value of impact parameter in units of nucleus radius RA;
- Sigin - total inelastic NN cross section at given "fSqrtS" (in mb);
- Sigjet - hard scattering NN cross section at given "fSqrtS" & "fPtmin" (in mb);
- Ntot - generated value of total event multiplicity (Ntot=Nhyd+Npyt);
- Nhyd - generated multiplicity of "soft" hydro-induced particles;
- Npyt - generated multiplicity of "hard" jet-induced particles;
- Njet - generated number of hard parton-parton scatterings with pt>fPtmin;
- Nbcol - mean number of binary NN sub-collisions at given "Bgen";
- Npart - mean number of nucleons-participants at given "Bgen".
- iJet - number of subevent (jet number). For hydro = 0

The event output tree "ROOT::TTree" is organized as follows:

  td->Branch("nev",&nev,"nev/I"); // event number  <br>
  td->Branch("Bgen",&Bgen,"Bgen/F"); // generated impact parameter <br>
  td->Branch("Sigin",&Sigin,"Sigin/F"); // total inelastic NN cross section <br>
  td->Branch("Sigjet",&Sigjet,"Sigjet/F"); // hard scattering NN cross section <br>
  td->Branch("Ntot",&Ntot,"Ntot/I"); // total event multiplicity <br>
  td->Branch("Nhyd",&Nhyd,"Nhyd/I"); // multiplicity of hydro-induced particles <br>
  td->Branch("Npyt",&Npyt,"Npyt/I"); // multiplicity of jet-induced particles <br>
  td->Branch("Njet",&Njet,"Njet/I"); // number of hard parton-parton scatterings <br>
  td->Branch("Nbcol",&Nbcol,"Nbcol/I");  // mean number of NN sub-collisions <br>
  td->Branch("Npart",&Npart,"Npart/I"); // mean number of nucleon-participants <br>
  td->Branch("Px",&Px[0],"Px[npart]/F"); // x-component of the momentum, in GeV/c <br>
  td->Branch("Py",&Py[0],"Py[npart]/F"); // y-component of the momentum, in GeV/c <br>
  td->Branch("Pz",&Pz[0],"Pz[npart]/F"); // z-component of the momentum, in GeV/c <br>
  td->Branch("E",&E[0],"E[npart]/F"); // energy, in GeV <br>
  td->Branch("X",&X[0],"X[npart]/F"); // x-coordinate at emission point, in fm <br>
  td->Branch("Y",&Y[0],"Y[npart]/F"); // y-coordinate at emission point, in fm <br>
  td->Branch("Z",&Z[0],"Z[npart]/F"); // z-coordinate at emission point, in fm <br>
  td->Branch("T",&T[0],"T[npart]/F"); // proper time of particle emission at emission point, in fm/c <br>
  td->Branch("pdg",&pdg[0],"pdg[npart]/I"); //Geant particle code <br>
  td->Branch("Mpdg",&Mpdg[0],"Mpdg[npart]/I"); // Geant code of mother particle, -1 for primordinary particles <br>
  td->Branch("type",&type[0],"type[npart]/I"); // origin of particle (=0 - from soft hydro part, >0 - from hard jet part) <br>
  td->Branch("iJet",&iJet[0],"iJet[npart]/I"); // number of sub-event (jets), 0 for hydro-part
  td->Branch("Index",&Index[0],"Index[Ntot]/I"); // unique zero based index of the particle <br>
  td->Branch("MotherIndex",&MotherIndex[0],"MotherIndex[Ntot]/I"); // index of the mother particle (-1 if its a primary particle) <br>
  td->Branch("NDaughters",&NDaughters[0],"NDaughters[Ntot]/I"); // number of daughter particles <br>
  td->Branch("FirstDaughterIndex",&FirstDaughterIndex[0],"FirstDaughterIndex[Ntot]/I"); // index of the first daughter (-1 if it does not exist) <br>
  td->Branch("LastDaughterIndex",&LastDaughterIndex[0],"LastDaughterIndex[Ntot]/I"); // index of the last daughter <br>
  td->Branch("pythiaStatus",&pythiaStatus[0],"pythiaStatus[Ntot]/I"); // PYTHIA status code (-1 if the particle is from soft component) <br>
  td->Branch("final",&final[0],"final[Ntot]/I"); // an integer branch keeping 1 for final state particles and 0 for decayed particles <br>
  td->Branch("iJet",&iJet[0],"iJet[Ntot]/I"); // an integer branch keeping number of subevent (all hydro particles has 0) <br>


  \section b_tab Impact parameters table

The ranges of impact parameters in the units of nuclear radius for different
centralities at RHIC (AuAu, 200 A GeV) and LHC (PbPb, 2760-5500 A GeV) are
specified below (the standard Woods-Saxon nucleon distribution is assumed).

<pre>
% centrality      b/RA (RHIC)        b/RA (LHC)
0                 0                  0 
5                 0.5                0.51 
6                 0.55               0.57 
10                0.72               0.74 
12                0.79               0.81 
15                0.89               0.91 
20                1.02               1.05 
25                1.15               1.18 
30                1.26               1.29 
35                1.36               1.39 
40                1.46               1.49 
45                1.55               1.58 
50                1.63               1.67 
55                1.71               1.75 
60                1.79               1.83 
65                1.86               1.90 
70                1.93               1.97 
75                2.01               2.06 
</pre>
 
 \page page2 Updates

\section updates Hydjet2 updates list

\subsection upt_2_4 HYDJET2.4: 1 February 2019

1. The strength of the elliptic and triangular flow fluctuations
   for soft component can be specified now by user in Hy2Input (by default)
   file with the new parameters 'fKeps2' and 'fKeps3' respectively.
2. Option to switch on/off elliptic, triangular and quadrangular
   modulations of the collective velocity profile for the alternative
   scenario of anisotropic flow treatment is introduced. It is controlled
   by the new parameters 'fRhou2', 'fRhou3' and 'fRhou4' respectively.
3. The bug related with the sometimes incorrect update of the
   particle coordinate information is fixed.
4. Several technical improvements have been done over the code to achieve
   better compatibility with latest Root versions and C++/Fortran
   compilers.

\subsection upt_2_3 HYDJET2.3: 30 November 2015

1. The additional elliptic and triangular flow fluctuations for soft
   component are introduced via event-by-event Gaussian smearing of
   the spatial anisotropy parameters.

\subsection upt_2_2 HYDJET2.2: 17 December 2013

1. The triangular flow for soft component is introduced via a special
   modulation of the freeze-out hypersurface. Third Fourier harmonic of
   azimuthal particle distribution appears relatively to new angle 'psiv3'
   (randomly distributed with respect to the direction of the impact
   parameter, and stored in array SERVICEEV at InitialStateHydjet.cxx).

2. The treatment of quadrangular flow for soft component is improved.

\subsection upt_2_1 HYDJET2.1: 6 July 2009

1. Option to get output from full particle history for PYTHIA/PYQUEN generated
   particles (including partons and strings) is introduced. It is controlled by
   the new flag:
   fIedit=1 - only final state particles are presented in event output,
   fIedit=0 - full particle history from PYTHIA/PYQUEN is produced.
   By default the full particle history is not produced, fIedit(D=1).

2. Option to produce thermal charmed particles (J/Psi and D mesons) is introduced.
   Total number of c-quarks is calculated with PYTHIA, and then thermal charmed
   hadrons are generated within the statistical hadronization model.
   It is controlled by the new flag:
   fIcharm=0 -  thermal charm production is switched off,
   fIcharm>=1 - thermal charm production is switched on),
   By default thermal charmed particle production is switched off, fIcharm(D=1).
   The new input parameters fMuC (chemical charm potential) and fCorrC (charmness
   enhancement factor) are inroduced. If fCorrC less than zero then is is calculated.

3. The decays of PYTHIA/PYQUEN generated particles are performed by PYTHIA decayer by
   default (instead of FASTMC decayer used before), mstj(21)(D=1).

4. Decay channels for K0 mesons are specified in "tabledecay.data" for FASTMC decayer.
   K0 is decayed in K0S(50%) and K0L(50%). K0S is further decayed, while K0L is
   considered stable.

5. Decay channels for J/Psi, D0+, D0-, D0 and D0-bar mesons are defined in
   "tabledecay.data" for FASTMC decayer. Only 2- and 3-body decays from PYTHIA
   tables are introduced meaning 77% of full branching for D0+ and D0- mesons,
   65% for D0 mesons and 12% for J/psi (the e+e- and mu+mu- channels).
   Other decay channels of J/Psi and D mesons are not produced.

6. Most of the PYTHIA particle codes are added into the particle definition list
   "particles.data" to accomodate the full particle history.

7. In the output tree, the "Daughter1Index", "Daughter2Index" and "Daughter3Index"
   branches were removed. Instead, the "FirstDaughterIndex" and "LastDaughterIndex"
   branches are introduced keeping the index of the first and last daughter,
   respectively. In the particle list, all daughter particles for a given particle
   are stored consecutively. If a particle has no daughters than these branches are
   -1. Some PYTHIA/PYQUEN particles have daughters but their first and last daughter
   indexes are -1. This happens for some PYTHIA status codes because PYTHIA keeps
   colour flow information instead of the daughter indexes. So the mother index can
   be used to reconstruct particle history if needed up to this level.

   In the output tree, the "pythiaStatus" branch was added. This will keep the
   PYTHIA status code k(i,1) for each particle from the hard component of HYDJET++
   (see PYTHIA manual for the code definitions). Particles from the soft component
   (type=1) have pythiaStatus=-1.

   In the output tree, the "final" branch was added. This is an integer branch keeping 1
   for final state particles and 0 for decayed particles. This flag can be used for
   particles from both hard and soft components. Final state particles can be    determined
   also in a more complicated way. For particles from hard component (type=1), the  final
   state particles must have pythiaStatus=1 and zero daughters. For particles from soft
   component (type=0), the final state particles must have zero daughters.

8. Makefile is modified. Now single Makefile is used for both root tree and histogram output.
   By default Makefile uses g77 as fortran compiler. If g77 is not found, Makefile switches
   to gfortran.

9. The file with default input parameters for c.m.s energy 2.76 A TeV "RunInputHydjetLHC2760"
   is added (3 March 2011).


    */
     

