/**
 
  \brief InitialParamsHydjet_t
  \details Virtual class for the initial state classes
  \authors Ludmila Malinina (malinina@lav01.sinp.msu.ru), SINP MSU/Moscow and JINR/Dubna
  Ionut Arsene (i.c.arsene@fys.uio.no), Oslo University and ISS-Bucharest

  \date 30 May 2007
*/

#ifndef INITIALSTATE
#define INITIALSTATE
// Include here common methods, but always declare them as virtual
#include "DatabasePDG.h"
#include "Particle.h"
#include "InitialParams.h"

class InitialState {

protected:
  DatabasePDG *fDatabase;
  InitialParamsHydjet_t fParams; ///< the list of initial state parameters
public:
  InitialState(InitialParamsHydjet_t &fParams) {
    fDatabase = new DatabasePDG(fParams);
    fDatabase->LoadData();
    fDatabase->SetMassRange(0.0, 200.);
    fDatabase->SetWidthRange(0., 10.);
  };
  virtual ~InitialState() {
    delete fDatabase;
  };

  virtual void Initialize(List_t &source, ParticleAllocator &hj_allocator, Double_t &bfix) = 0;
  virtual Bool_t ReadParams(InitialParamsHydjet_t &) = 0;
  virtual Bool_t MultIni() = 0;
  virtual Bool_t RunDecays() = 0;
  virtual Double_t GetWeakDecayLimit() = 0;

  virtual void Evolve(List_t &secondaries, ParticleAllocator &hj_allocator, Double_t weakDecayLimit);
};

#endif
