/**
 
  \brief InitalStateHydjet
  \authors Nikolai Amelin (amelin@sunhe.jinr.ru), Ludmila Malinina (malinina@sunhe.jinr.ru), Timur Pocheptsov (pocheptsov@sunhe.jinr.ru) 
  \date 2 Nov 2005
  \copyright JINR/Dubna
*/

#ifndef INITIALSTATEHYDJET_INCLUDED
#define INITIALSTATEHYDJET_INCLUDED

#include "DatabasePDG.h"
#include "InitialState.h"
#include "Particle.h"

class InitialStateHydjet : public InitialState {
private:
  Double_t fVolEff; ///< the effective volume
  Int_t fNPartTypes;        ///< counter of hadron species
  Int_t fPartEnc[1000];     ///< Hadron encodings. Maximal number of hadron species is 1000!!!
  Double_t fPartMult[2000]; ///< Multiplicities of hadron species
  Double_t fPartMu[2000];   ///< Chemical potentials of hadron species
  Double_t fNocth; ///< open charm
  Double_t fNccth;


public:
  InitialStateHydjet(InitialParamsHydjet_t &fParams): InitialState(fParams){};
  ~InitialStateHydjet(){};

  void SetVolEff(Double_t value) { fVolEff = value; }
  Double_t GetVolEff() { return fVolEff; }
  virtual Bool_t RunDecays() { return (fParams.fDecay > 0 ? kTRUE : kFALSE); }
  virtual Double_t GetWeakDecayLimit() { return fParams.fWeakDecay; }

  virtual void Initialize(List_t &source, ParticleAllocator &hj_allocator, Double_t &bfix);
  virtual Bool_t ReadParams(InitialParamsHydjet_t&);
  virtual Bool_t MultIni();
  Bool_t IniOfThFreezeoutParameters();

  Double_t f(Double_t);
  Double_t f2(Double_t, Double_t, Double_t);

  Double_t SimpsonIntegrator(Double_t, Double_t, Double_t, Double_t);
  Double_t SimpsonIntegrator2(Double_t, Double_t, Double_t, Double_t);
  Double_t MidpointIntegrator2(Double_t, Double_t, Double_t, Double_t);

  Double_t CharmEnhancementFactor(Double_t, Double_t, Double_t, Double_t);
};

#endif
