
#include "Hydjet2.h"

#include "InitialState.h"
#include "InitialStateHydjet.h"
#include "Particle.h"
//#include "DatabasePDG.h"

#include <TRandom.h>
#include <TMath.h>

#include "Hydjet2Wrapper.h"

InitialState *FASTMC;
ParticleAllocator hj_allocator;
List_t particleList;


Hydjet2::Hydjet2(InitialParamsHydjet_t &inputParameters) {
 
  HYJVER(cm, va, vb, vc); Version.at(0)=va; Version.at(1)=vb; Version.at(2)=vc;

 if(inputParameters.doPrintInfo){          
  std::cout << " *******************************************************************************" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *    event generator under the ROOT FRAMEWORK for simulation of               *" << std::endl;
  std::cout << " *    relativistic heavy ion AA collisions as a superposition of the           *" << std::endl;
  std::cout << " *    soft, hydro-type state and hard, multi-parton state.                     *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     The main routine is written in the object-oriented C++ language         *" << std::endl;
  std::cout << " *     under the ROOT environment. The hard, multi-partonic part of            *" << std::endl;
  std::cout << " *     HYDJET++ event is identical to the hard part of Fortran-written         *" << std::endl;
  std::cout << " *     HYDJET (PYTHIA6.4xx + PYQUEN1.5.x) and is included in the generator     *" << std::endl;
  std::cout << " *     structure as the separate directory. The soft part of HYDJET++          *" << std::endl;
  std::cout << " *     event represents the thermal hadronic state obtained with the           *" << std::endl;
  std::cout << " *     Bjorken-like parameterization of freeze-out hypersurface and            *" << std::endl;
  std::cout << " *     includes longitudinal, radial and elliptic flow effects and             *" << std::endl;
  std::cout << " *     decays of hadronic resonances. The corresponding fast                   *" << std::endl;
  std::cout << " *     Monte-Carlo simulation procedure (C++ code) FAST MC is adapted.         *" << std::endl;
  std::cout << " *     --------------------------------------------------------------          *" << std::endl;
  std::cout << " *     Web-page:                                                               *" << std::endl;
  std::cout << " *     http://cern.ch/lokhtin/hydjet++                                         *" << std::endl;
  std::cout << " *     --------------------------------------------------------------          *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " * This program is a free software, one can use and redistribute it freely.    *" << std::endl;
  std::cout << " * Any publication of results obtained using this code must reference          *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Main reference for HYDJET++:                                            *" << std::endl;
  std::cout << " *     I.P. Lokhtin, L.V. Malinina, S.V. Petrushanko, A.M. Snigirev,           *" << std::endl;
  std::cout << " *     I. Arsene, K. Tywoniuk, Comp. Phys. Comm. 180 (2009) 779                *" << std::endl;
  std::cout << " *     http://cern.ch/lokhtin/hydjet++.                                        *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Reference for HYDJET and PYQUEN:                                        *" << std::endl;
  std::cout << " *     I.P. Lokhtin, A.M. Snigirev, Eur. Phys. J. C 46 (2006) 211              *" << std::endl;
  std::cout << " *     http://cern.ch/lokhtin/hydro/hydjet.html                                *" << std::endl;
  std::cout << " *     http://cern.ch/lokhtin/pyquen.                                          *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Reference for PYTHIA6.4:                                                *" << std::endl;
  std::cout << " *     T.Sjostrand, S. Mrenna and P. Skands, JHEP05 (2006) 026;                *" << std::endl;
  std::cout << " *     http://home.thep.lu.se/~torbjorn/Pythia.html.                           *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     References for FAST MC:                                                 *" << std::endl;
  std::cout << " *     N.S. Amelin, R. Lednicky, T.A. Pocheptsov, I.P. Lokhtin,                *" << std::endl;
  std::cout << " *     L.V. Malinina, A.M. Snigirev, Iu.A. Karpenko and Yu.M. Sinyukov,        *" << std::endl;
  std::cout << " *     Phys. Rev. C 74 (2006) 064901;                                          *" << std::endl;
  std::cout << " *     N.S. Amelin, I. Arsene, L. Bravina, Iu.A. Karpenko, R. Lednicky,        *" << std::endl;
  std::cout << " *     I.P. Lokhtin, L.V. Malinina, A.M. Snigirev and Yu.M. Sinyukov,          *" << std::endl;
  std::cout << " *     Phys. Rev. C 77 (2008) 014903                                           *" << std::endl;
  std::cout << " *     http://uhkm.jinr.ru.                                                    *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Reference for nuclear shadowing model:                                  *" << std::endl;
  std::cout << " *     K. Tywoniuk, I.C. Arsene, L. Bravina, A. Kaidalov and                   *" << std::endl;
  std::cout << " *     E. Zabrodin, Phys. Lett. B 657 (2007) 170.                              *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Version 2.4:                                                            *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Igor Lokhtin, SINP MSU, Moscow, RU                                      *" << std::endl;
  std::cout << " *     e-mail: Igor.Lokhtin@cern.ch                                            *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *     Ludmila Malinina, SINP MSU, Moscow, RU                                  *" << std::endl;
  std::cout << " *     e-mail: malinina@lav01.sinp.msu.ru                                      *" << std::endl;
  std::cout << " *                                                                             *" << std::endl;
  std::cout << " *******************************************************************************" << std::endl;
  }

  FASTMC = new InitialStateHydjet(inputParameters);

  if (!FASTMC->ReadParams(inputParameters)) {
    Error("RunHadronSource::main", "No initial model parameters found!!\n");
    std::cout<<"Initial multiplicities are zero!!"<<std::endl;
    exit(0);
    return;
  }

  if (!FASTMC->MultIni()) {
    Error("RunHadronSource::main", "Initial multiplicities are zero!!\n");
    std::cout<<"Initial multiplicities are zero!!"<<std::endl;
    exit(0);
    return;
  }

  nev = inputParameters.fNevnt;
  if(inputParameters.doPrintInfo) std::cout << "Seed for random number generation= " << gRandom->GetSeed() << std::endl;

  FirstEv=true;
}

Hydjet2::~Hydjet2() {
}

void Hydjet2::GenerateEvent(Double_t &bfix) {

  pdg.clear();
  Mpdg.clear();
  type.clear();
  pythiaStatus.clear();
  Px.clear();
  Py.clear();
  Pz.clear();
  E.clear();
  X.clear();
  Y.clear();
  Z.clear();
  T.clear();
  Index.clear();
  MotherIndex.clear();
  NDaughters.clear();
  FirstDaughterIndex.clear();
  LastDaughterIndex.clear();
  iJet.clear();
  ifFinal.clear();

  emptyEvent = false;

  // Initialize the source
  FASTMC->Initialize(particleList, hj_allocator, bfix);

  Bgen = (Double_t)HYFPAR.bgen;
  Npart = (Int_t)HYFPAR.npart;
  Nbcol = (Int_t)HYFPAR.nbcol;
  Njet = (Int_t)HYJPAR.njet;
  v3psi = (Double_t)SERVICEEV.psiv3;
  
  if(FirstEv) {
    Sigin=HYJPAR.sigin;
    Sigjet=HYJPAR.sigjet;
    FirstEv=false;
  }

  if (particleList.empty()) {
    emptyEvent = true;
    return;
  } else if (FASTMC->RunDecays())
    FASTMC->Evolve(particleList, hj_allocator, FASTMC->GetWeakDecayLimit());

  LPIT_t it;
  LPIT_t e;

  // Fill the decayed tree
  Ntot = 0;
  Nhyd = 0;
  Npyt = 0;
  if (!particleList.empty())
    for (it = particleList.begin(), e = particleList.end(); it != e; ++it) {
      TVector3 pos(it->Pos().Vect());
      TVector3 mom(it->Mom().Vect());
      Float_t m1 = it->TableMass();
      pdg.push_back(it->Encoding());
      Mpdg.push_back(it->GetLastMotherPdg());
      Px.push_back(mom[0]);
      Py.push_back(mom[1]);
      Pz.push_back(mom[2]);
      E.push_back(TMath::Sqrt(mom.Mag2() + m1 * m1));
      X.push_back(pos[0]);
      Y.push_back(pos[1]);
      Z.push_back(pos[2]);
      T.push_back(it->T());
      type.push_back(it->GetType());
      pythiaStatus.push_back(it->GetPythiaStatusCode());
      Index.push_back(it->GetIndex());
      MotherIndex.push_back(it->GetMother());
      NDaughters.push_back(it->GetNDaughters());
      Int_t FDI = -1; FDI = (it->GetFirstDaughterIndex());
      Int_t LDI = -1; LDI = (it->GetLastDaughterIndex());
      iJet.push_back(it->GetiJet());
      // index of first daughter
      FirstDaughterIndex.push_back(FDI);
      // index of last daughter
      LastDaughterIndex.push_back(LDI);
      if (type[Ntot] == 1) { // jets
        if (pythiaStatus[Ntot] == 1 &&
            NDaughters[Ntot] == 0) // code for final state particle in pythia
          ifFinal.push_back(1);
        else
          ifFinal.push_back(0);
      }
      if (type[Ntot] == 0) { // hydro
        if (NDaughters[Ntot] == 0)
          ifFinal.push_back(1);
        else
          ifFinal.push_back(0);
      }

      if (type[Ntot] == 0)
        Nhyd++;
      if (type[Ntot] == 1)
        Npyt++;

      Ntot++;
      if (Ntot > 500000)
        Error("in main:", "Ntot is too large %d", Ntot);
    }

  hj_allocator.FreeList(particleList);
}
